@@ -24,14 +24,14 @@ Simple usage:
     
     make_server('', 8000, app).serve_forever()
 
-Copyright (c) 2007-2008 Vsevolod S. Balashov under terms of GNU LGPL v.2.1
+Copyright (c) 2007 - present Vsevolod S. Balashov under terms of GNU LGPL v.2.1
 
 TODO more docstrings
 '''
 
-__author__ = "Vsevolod Balashov"
-__email__ = "vsevolod at balashov dot name"
-#TODO __version__ = "$Revision$"
+__author__  = "Vsevolod Balashov"
+__email__   = "vsevolod@balashov.name"
+__version__ = "0.8.1"
 
 from storm.database import Database, create_database
 from storm.store import Store
